Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1602)

Unified Diff: content/common/view_messages.h

Issue 177863007: Replace WebDocument::clearfocusedNode to clearFocusedElement (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebased with latest Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/render_view_host_impl.cc ('k') | content/public/browser/render_view_host.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/view_messages.h
diff --git a/content/common/view_messages.h b/content/common/view_messages.h
index 357c8ce5e22e9977c1cd0c2b78aa86ce2b666e19..aaf77b94c1181932964f6fa067a8b4cc9bcc1025 100644
--- a/content/common/view_messages.h
+++ b/content/common/view_messages.h
@@ -1043,8 +1043,8 @@ IPC_MESSAGE_ROUTED1(ViewMsg_DisableAutoResize,
IPC_MESSAGE_ROUTED1(ViewMsg_SetTextDirection,
blink::WebTextDirection /* direction */)
-// Tells the renderer to clear the focused node (if any).
-IPC_MESSAGE_ROUTED0(ViewMsg_ClearFocusedNode)
+// Tells the renderer to clear the focused element (if any).
+IPC_MESSAGE_ROUTED0(ViewMsg_ClearFocusedElement)
// Make the RenderView transparent and render it onto a custom background. The
// background will be tiled in both directions if it is not large enough.
« no previous file with comments | « content/browser/renderer_host/render_view_host_impl.cc ('k') | content/public/browser/render_view_host.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698